@@ -7,10 +7,10 @@ try:
     from .logger import PortholeLogger
     from .mailer import Mailer
     from .related_record import RelatedRecord, ChildRecord
-    from .reports import BasicReport, GenericReport
-    from .queries import QueryGenerator, QueryReader, QueryResult
+    from .reports import BasicReport, GenericReport, ReportRunner
+    from .queries import QueryExecutor, QueryGenerator, QueryReader, QueryResult
     from .workflows import SimpleWorkflow
     from .xlsx import WorkbookBuilder
 except KeyError:
     print("Unable to import Porthole due to KeyError. Check config/config.ini.")
-    print("{}: {}".format(sys.exc_info()[1].__doc__, sys.exc_info()[1]))
\ No newline at end of file
+    print("{}: {}".format(sys.exc_info()[1].__doc__, sys.exc_info()[1]))
